gmr
===

Gaussian Mixture Models (GMMs) for clustering and regression in Python.

Source code repository: https://github.com/AlexanderFabisch/gmr

Installation
------------

    sudo pip install gmr

or

    sudo python setup.py install
